# -*- coding: utf-8 -*-
u"""
    pylatex.pgfplots
    ~~~~~~~~~~~~~~~~

    This module implements the classes used to show plots.

    :copyright: (c) 2014 by Jelte Fennema.
    :license: MIT, see License for more details.
"""


from __future__ import absolute_import
from pylatex.base_classes import BaseLaTeXClass, BaseLaTeXNamedContainer
from pylatex.package import Package
from pylatex.command import Command


class TikZ(BaseLaTeXNamedContainer):

    u"""Basic TikZ container class."""

    container_name = u'tikzpicture'

    def __init__(self, data=None):
        u"""
            :param data:

            :type data: list
        """

        packages = [Package(u'tikz')]

        super(TikZ, self).__init__(data=data, packages=packages)


class Axis(BaseLaTeXNamedContainer):

    u"""PGFPlots axis container class, this contains plots."""

    def __init__(self, data=None, options=None):
        u"""
            :param data:
            :param options:

            :type data: list
            :type options: str or list or :class:`parameters.Options` instance
        """

        packages = [Package(u'pgfplots'), Command(u'pgfplotsset',
                                                 u'compat=newest')]

        super(Axis, self).__init__(data=data, options=options, packages=packages)


class Plot(BaseLaTeXClass):

    u"""PGFPlot normal plot."""

    def __init__(self, name=None, func=None, coordinates=None, options=None):
        u"""
            :param name:
            :param func:
            :param coordinates:
            :param options:

            :type name: str
            :type func: str
            :type coordinates: list
            :type options: str or list or :class:`parameters.Options` instance
        """

        self.name = name
        self.func = func
        self.coordinates = coordinates
        self.options = options

        packages = [Package(u'pgfplots'), Command(u'pgfplotsset',
                                                 u'compat=newest')]

        super(Plot, self).__init__(packages=packages)

    def dumps(self):
        u"""Represents the plot as a string in LaTeX syntax.

            :return:
            :rtype: str
        """

        string = Command(u'addplot', options=self.options).dumps()

        if self.coordinates is not None:
            string += u' coordinates {\n'

            for x, y in self.coordinates:
                string += u'(' + unicode(x) + u',' + unicode(y) + u')\n'
            string += u'};\n\n'

        elif self.func is not None:
            string += u'{' + self.func + u'};\n\n'

        if self.name is not None:
            string += Command(u'addlegendentry', self.name).dumps()

        super(Plot, self).dumps()

        return string
